@@ -15,7 +15,7 @@ class Recipe:
         download_dir = self.buildout['buildout']['download-directory']
         version = self.options.get('version')
         if version is None:
-            version = '1.20'
+            version = '1.21'
         else:
             version = version.strip()
         if not os.path.isdir(download_dir):
@@ -62,6 +62,7 @@ class Recipe:
                    'MAILDROP_PASSWORD':'string',
                    'WAIT_INTERVAL':'number',
                    'ADD_MESSAGEID':'number',
+                   'SUPERVISED_DAEMON':'number',
                   }
         
         # prepare list of values
@@ -77,7 +78,7 @@ class Recipe:
                     raise Exception, 'Unknown variable type'
         
         # read old configuration
-        config = open(os.path.join(result, 'config.py'), 'r')
+        config = open(os.path.join(result, 'config.py'), 'rU')
         old_config = config.readlines()
         config.close()
         
@@ -94,6 +95,38 @@ class Recipe:
             if not processed:
                 config.write(line)
         config.close()
+        
+        # write control script to ${buildout:directory}/bin
+        buildout_dir = self.buildout['buildout']['directory']
+        # read maildropctl file
+        fp = open(os.path.join(target, 'MaildropHost', 'maildrop', 'bin', 'maildropctl'), 'rU')
+        old_ctl = fp.readlines()
+        fp.close()
+        
+        # write new (configured) control file
+        new_ctl_filename = os.path.join(buildout_dir, 'bin', 'maildropctl')
+        new_ctl = open(new_ctl_filename, 'w')
+        for line in old_ctl:
+            processed = False
+            if line.startswith('MAILDROP_DIR'):
+                new_ctl.write('MAILDROP_DIR="%s"\n' % os.path.join(result, 'maildrop'))
+                processed = True
+            if line.startswith('MAILDROP_CONFIG_FILE'):
+                new_ctl.write('MAILDROP_CONFIG_FILE="%s"\n' % os.path.join(result, 'config.py'))
+                processed = True
+            if line.startswith('MAILDROP_USER'):
+                # maildrop user will be read from options or will be the same as current user
+                v = self.options.get('MAILDROPN_USER')
+                if v is not None:
+                    new_ctl.write('MAILDROP_USER="%s"\n' % v)
+                else:
+                    new_ctl.write('MAILDROP_USER=`id -un`\n')
+                processed = True
+            if not processed:
+                new_ctl.write(line)
+        new_ctl.close()
+        os.chmod(new_ctl_filename, 0755)
+        print "Wrote %s" % new_ctl_filename
         return result
 
     def update(self):
